@@ -1,4 +1,15 @@
-//@line 39 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/toolkit/content/nsDragAndDrop.js"
+//@line 39 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/toolkit/content/nsDragAndDrop.js"
+
+////////////////////////////////////////////////////////////////////////
+//
+// USE OF THIS API FOR DRAG AND DROP IS DEPRECATED!
+// Do not use this file for new code.
+//
+// For documentation about what to use instead, see:
+//   http://developer.mozilla.org/En/DragDrop/Drag_and_Drop
+//
+////////////////////////////////////////////////////////////////////////
+
 
 /** 
  *  nsTransferable - a wrapper for nsITransferable that simplifies
@@ -565,7 +576,12 @@ var nsDragAndDrop = {
       var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                              .getService(nsIScriptSecurityManager);
 
+      if (!aDragSession)
+        aDragSession = this.mDragService.getCurrentSession();
+
       var sourceDoc = aDragSession.sourceDocument;
+      // Use "file:///" as the default sourceURI so that drops of file:// URIs
+      // are always allowed.
       var sourceURI = sourceDoc ? sourceDoc.documentURI : "file:///";
 
       try {
