@@ -161,13 +161,17 @@ pref("gfx.color_management.display_profile", "");
 pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
+pref("gfx.downloadable_fonts.sanitize", true);
+//@line 176 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
+//@line 178 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 179 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 185 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -180,7 +184,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 195 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 201 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -524,9 +528,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 539 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 545 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 541 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 547 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -575,7 +579,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 592 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 598 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -711,6 +715,7 @@ pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
+pref("network.IDN.whitelist.il", true);
 pref("network.IDN.whitelist.io", true);
 pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
@@ -734,12 +739,28 @@ pref("network.IDN.whitelist.vn", true);
 // IDN ccTLDs
 // ae, UAE, .<Emarat>
 pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
-// sa, Saudi Arabia, .<al-Saudiah>
-pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
-// ru, Russian Federation, .<RF>
-pref("network.IDN.whitelist.xn--p1ai", true);
+// cn, China, .<China> with variants
+pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
+pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// hk, Hong Kong, .<Hong Kong>
+pref("network.IDN.whitelist.xn--j6w193g", true);
+// ir, Iran, <.Iran> with variants
+pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
+pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// qa, Qatar, .<Qatar>
+pref("network.IDN.whitelist.xn--wgbl6a", true);
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// sa, Saudi Arabia, .<al-Saudiah> with variants
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
+pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
+pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// tw, Taiwan, <.Taiwan> with variants
+pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
+pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
 pref("network.IDN.whitelist.biz", true);
@@ -827,7 +848,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 849 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 872 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1248,15 +1269,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1667 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 1690 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2091 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2114 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2294 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2317 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2390 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2413 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2393 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2416 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1526,20 +1547,20 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2665 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2688 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2733 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2756 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2759 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2782 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2779 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2802 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2781 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2804 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2787 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2810 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1576,9 +1597,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2829 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2852 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2834 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2857 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
