@@ -1,4 +1,4 @@
-//@line 38 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/toolkit/mozapps/extensions/content/update.js"
+//@line 38 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/toolkit/mozapps/extensions/content/update.js"
 
 // This UI is only opened from the Extension Manager when the app is upgraded.
 
@@ -155,7 +155,8 @@ var gVersionInfoPage = {
     var em = Components.classes["@mozilla.org/extensions/manager;1"]
                        .getService(nsIExtensionManager);
     // Synchronize the app compatibility info for all items.
-    em.update([], 0, nsIExtensionManager.UPDATE_SYNC_COMPATIBILITY, this);
+    em.update([], 0, nsIExtensionManager.UPDATE_SYNC_COMPATIBILITY, this,
+              nsIExtensionManager.UPDATE_WHEN_NEW_APP_INSTALLED);
   },
 
   /////////////////////////////////////////////////////////////////////////////
@@ -168,7 +169,7 @@ var gVersionInfoPage = {
     var em = Components.classes["@mozilla.org/extensions/manager;1"]
                        .getService(nsIExtensionManager);
     // Retrieve the remaining incompatible items.
-    gUpdateWizard.items = em.getIncompatibleItemList(null, null, null,
+    gUpdateWizard.items = em.getIncompatibleItemList(null, null,
                                                      nsIUpdateItem.TYPE_ANY,
                                                      true, { });
     gUpdateWizard.items = gUpdateWizard.items.filter(function(item) {
@@ -268,7 +269,8 @@ var gUpdatePage = {
     var em = Components.classes["@mozilla.org/extensions/manager;1"]
                        .getService(nsIExtensionManager);
     em.update(gUpdateWizard.items, this._totalCount,
-              nsIExtensionManager.UPDATE_CHECK_NEWVERSION, this);
+              nsIExtensionManager.UPDATE_CHECK_NEWVERSION, this,
+              nsIExtensionManager.UPDATE_WHEN_NEW_APP_INSTALLED);
   },
 
   /////////////////////////////////////////////////////////////////////////////
